#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "RIO_2010_AIO.h"

void parseTemperature(unsigned char *raw_data_buf, int total_len)
{
	int i, idx=0;
	int t_ls, t_ms;
	double t_value;
	do {
		printf("Sensor ID:\r\n");
		for(i=0; i<8; i++) {
			printf("0x%x,", raw_data_buf[idx++]);
		}
		printf("\r\n");
		t_ls = raw_data_buf[idx++];
		t_ms = raw_data_buf[idx++];
		idx += 6;
		t_value = 0;
		for(i=0;i<4;i++) {
			if (((t_ls>>i)&1)==1) {
				t_value += 1 / pow(2,(4-i));
			}
		}
		for(;i<8;i++) {
			if (((t_ls>>i)&0x01)==0x01){
				t_value += pow(2,(i-4));
			}
		}
		for(i=0;i<3;i++) {
			if (((t_ms>>i)&0x01)==0x01){
				t_value += pow(2,(i+4));
			}
		}
		printf("Temperature: %f degrees Celsius\r\n", t_value);
	} while(idx < total_len);	
}

int main(int argc, char *argv[])
{
	int i, ret, fd;
	unsigned char response_buf[64];
	int response_byte_count;

	printf("RIO-2010 Sensor Read Example.\r\n");

	ret = AIO_Init();
	if (ret != AIO_OK) {
		printf("AIO_Init Error: %d.\r\n", ret);
		return -1;
	}
	
	ret = AIO_Connect("192.168.2.127", 502, 1000, &fd);
	if (ret != AIO_OK) {
		printf("AIO_Connect Error: %d.\r\n", ret);
		return -1;
	}

	ret = AIO_RIO_2010_Sensor_Read(fd, 100, response_buf, sizeof(response_buf), &response_byte_count);
	if (ret != AIO_OK) {
		printf("AIO_RIO_2010_Sensor_Read Error: %d.\r\n", ret);
		if (ret == AIO_MB_EXCEPTION) {
			printf("Modbus exception code: 0x%02x.\r\n", response_buf[0]);
		}
	} else {
		printf("Sensor Read Response:\r\n");
		for(i=0; (i<response_byte_count)&&(i<sizeof(response_buf)); i++) {
			if ((i%8)==0 && (i!=0)) {
				printf("\r\n");
			}
			printf("[%02d]:0x%02x,", i, response_buf[i]);
		}
		printf("\r\n");
		parseTemperature(response_buf, response_byte_count);
	}

	AIO_Close(fd);

	printf("Example Exit.\r\n");
	return 0;
}


