#include <stdio.h>
#include <stdlib.h>
#include "RIO_2017_AIO.h"

#define AI_RANGE_150MV	0x00
#define AI_RANGE_500MV	0x02
#define AI_RANGE_1V		0x04
#define AI_RANGE_5V		0x06
#define AI_RANGE_10V	0x08
#define AI_RANGE_20MA	0x0a

int main(int argc, char *argv[])
{
	int i, ret, fd, set_val;
	unsigned char response_buf[32];
	int response_byte_count;

	printf("RIO-2017 Set AI enable/range Example.\r\n");

	ret = AIO_Init();
	if (ret != AIO_OK) {
		printf("AIO_Init Error: %d.\r\n", ret);
		return -1;
	}
	
	ret = AIO_Cfg_Login("192.168.2.127", 5001, 1000, "", &fd);
	if (ret != AIO_OK) {
		printf("AIO_Cfg_Login Error: %d.\r\n", ret);
		return -1;
	}

	ret = AIO_Cfg_RIO_2017_Get_AI_Enable(fd, 100, 1, 8, response_buf, sizeof(response_buf), &response_byte_count);
	if (ret != AIO_OK) {
		printf("AIO_Cfg_RIO_2017_Get_AI_Enable Error: %d.\r\n", ret);
		if (ret == AIO_UNKNOWN_RESP) {
			printf("unknown response: %s\r\n", response_buf);
		}
	} else {
		printf("Get AI_Enable:\r\n");
		for(i=0; (i<response_byte_count)&&(i<sizeof(response_buf)); i++) {
			printf("[%d]:0x%02x\r\n", i, response_buf[i]);
		}
	}

	set_val = 0x55;
	ret = AIO_Cfg_RIO_2017_Set_AI_Enable(fd, 100, 1, 8, set_val);
	if (ret != AIO_OK) {
		printf("AIO_Cfg_RIO_2017_Set_AI_Enable Error: %d.\r\n", ret);
	} else {
		printf("Set AI_Enable 0x%x OK\r\n", set_val);
	}

	ret = AIO_Cfg_RIO_2017_Get_AI_Range(fd, 100, 1, 8, response_buf, sizeof(response_buf), &response_byte_count);
	if (ret != AIO_OK) {
		printf("AIO_Cfg_RIO_2017_Get_AI_Range Error: %d.\r\n", ret);
		if (ret == AIO_UNKNOWN_RESP) {
			printf("unknown response: %s\r\n", response_buf);
		}
	} else {
		printf("Get AI_Range:\r\n");
		for(i=0; (i<response_byte_count)&&(i<sizeof(response_buf)); i++) {
			printf("AI-StartAddr[%d]:", i);
			switch(response_buf[i]) {	
			case AI_RANGE_0_150MV:
				printf("0~150MV\r\n");
			break;
			case AI_RANGE_N150_150MV:
				printf("-150~150MV\r\n");
			break;
			case AI_RANGE_0_500MV:
				printf("0~500MV\r\n");
			break;
			case AI_RANGE_N500_500MV:
				printf("-500~500MV\r\n");
			break;
			case AI_RANGE_0_1V:
				printf("0~1V\r\n");
			break;
			case AI_RANGE_N1_1V:
				printf("-1~1V\r\n");
			break;
			case AI_RANGE_0_5V:
				printf("0~5V\r\n");
			break;
			case AI_RANGE_N5_5V:
				printf("-5~5V\r\n");
			break;
			case AI_RANGE_0_10V:
				printf("0~10V\r\n");
			break;
			case AI_RANGE_N10_10V:
				printf("-10~10V\r\n");
			break;
			case AI_RANGE_0_20MA:
				printf("0~20MA\r\n");
			break;
			}
		}
	}

	response_buf[0] = AI_RANGE_0_20MA;
	response_buf[1] = AI_RANGE_0_10V;
	response_buf[2] = AI_RANGE_N10_10V;
	response_buf[3] = AI_RANGE_0_5V;
	response_buf[4] = AI_RANGE_N5_5V;
	response_buf[5] = AI_RANGE_0_1V;
	response_buf[6] = AI_RANGE_N1_1V;
	response_buf[7] = AI_RANGE_0_500MV;

	ret = AIO_Cfg_RIO_2017_Set_AI_Range(fd, 100, 1, 8, response_buf, sizeof(response_buf));
	if (ret != AIO_OK) {
		printf("AIO_Cfg_RIO_2017_Set_AI_Range Error: %d.\r\n", ret);
		if (ret == AIO_UNKNOWN_RESP) {
			printf("unknown response: %s\r\n", response_buf);
		}
	} else {
		printf("Set AI_Range OK\r\n");
	}

	AIO_Cfg_SaveExit(fd);

	printf("Example Exit.\r\n");
	return 0;
}


