#include <stdio.h>
#include <stdlib.h>
#include "RIO_2018_AIO.h"

void parseTCdata(unsigned char *raw_data_buf, int total_len)
{
	int idx=0;
	unsigned char enable, sign_flag, sign_rf_flag, fault;
	int tc_integer, tc_decimal;
	unsigned char rf_integer, rf_decimal;
	do {
		enable = raw_data_buf[idx++];
		sign_flag = raw_data_buf[idx++];

		tc_integer = raw_data_buf[idx++]*0x100;
		tc_integer += raw_data_buf[idx++];

		tc_decimal = raw_data_buf[idx++]*0x100;
		tc_decimal += raw_data_buf[idx++];

		rf_integer = raw_data_buf[idx++];
		rf_decimal = raw_data_buf[idx++];

		sign_rf_flag = raw_data_buf[idx++];
		fault = raw_data_buf[idx++];

		printf("TC:");
		if (enable == 0x01) {
			printf("enable,");
		} else {
			printf("disable,");
		}
		if ((fault&0x01) == 0x01) {
			printf("Fault:%s\r\n", "Open");
		}
		if ((fault&0x02) == 0x02) {
			printf("Fault:%s\r\n", "Short to GND");
		}
		if ((fault&0x04) == 0x04) {
			printf("Fault:%s\r\n", "Short to VCC");
		}
		printf("Temperature:");
		if (sign_flag == 0x01) {
			printf("-");
		}
		printf("%d.%d\r\n", tc_integer, tc_decimal);

		printf("Reference:");
		if (sign_rf_flag == 0x01) {
			printf("-");
		}
		printf("%d.%d\r\n", rf_integer, rf_decimal);
	} while(idx < total_len);	
}

int main(int argc, char *argv[])
{
	int i, ret, fd;
	unsigned char response_buf[64];
	int response_byte_count;

	printf("RIO-2018 TC Read Example.\r\n");

	ret = AIO_Init();
	if (ret != AIO_OK) {
		printf("AIO_Init Error: %d.\r\n", ret);
		return -1;
	}
	
	ret = AIO_Connect("192.168.2.127", 502, 1000, &fd);
	if (ret != AIO_OK) {
		printf("AIO_Connect Error: %d.\r\n", ret);
		return -1;
	}

	ret = AIO_RIO_2018_TC_Read(fd, 100, 1, 3, response_buf, sizeof(response_buf), &response_byte_count);
	if (ret != AIO_OK) {
		printf("AIO_RIO_2018_TC_Read Error: %d.\r\n", ret);
		if (ret == AIO_MB_EXCEPTION) {
			printf("Modbus exception code: 0x%02x.\r\n", response_buf[0]);
		}
	} else {
		printf("TC Read Response:\r\n");
		for(i=0; (i<response_byte_count)&&(i<sizeof(response_buf)); i++) {
			if ((i%10)==0 && (i!=0)) {
				printf("\r\n");
			}
			printf("[%02d]:0x%02x,", i, response_buf[i]);
		}
		printf("\r\n");
		parseTCdata(response_buf, response_byte_count);
	}

	AIO_Close(fd);

	printf("Example Exit.\r\n");
	return 0;
}


